@@ -16,4 +16,4 @@
 #   You should have received a copy of the GNU General Public License
 #   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""Database-related classes"""
+"""Database-related classes."""
