@@ -31,3 +31,8 @@ class BaseItemSaver:
     def __init__(self, shutdown):
         """Initialise an BaseItemSaver."""
         self.shutdown = shutdown
+        self.counts = {
+            "likes": 0,
+            "tweets": 0,
+            "users": 0
+        }
