@@ -36,10 +36,11 @@ class MediaItemSaver(BaseItemSaver):
             media_item = session.get(MediaItem, data["media_key"])
 
             if media_item is None:
-                media_item = MediaItem(
-                    media_key=data["media_key"],
-                    url=data["url"]
-                )
+                media_item = MediaItem(media_key=data["media_key"])
+
+                if "url" in data:
+                    media_item.url = data["url"]
+
                 media_item.media_type = (
                     session.query(MediaType)
                     .filter(MediaType.media_type == data["type"])
