@@ -121,6 +121,10 @@ class Tweet(Base):
 
     like_count = sqlalchemy.Column(sqlalchemy.BigInteger)
 
+    liked_by = sqlalchemy.orm.relationship(
+        "User", secondary="likes", back_populates="likes"
+    )
+
     place_id = sqlalchemy.Column(
         sqlalchemy.Text,
         sqlalchemy.ForeignKey("places.id"),
