@@ -62,7 +62,8 @@ class UserSaver(BaseItemSaver):
                 if "location" in data:
                     user.location = data["location"]
 
-                user.created_at = dateparser.parse(data["created_at"])
+                if data["created_at"]:
+                    user.created_at = dateparser.parse(data["created_at"])
 
                 if "pinned_tweet_id" in data:
                     user.pinned_tweet = (
@@ -123,4 +124,6 @@ class UserSaver(BaseItemSaver):
                     user.tweet_count = data["public_metrics"]["tweet_count"]
                     user.listed_count = data["public_metrics"]["listed_count"]
 
+                self.counts["users"] += 1
+
         return user
