@@ -32,6 +32,7 @@ import requests.exceptions
 
 from ..exceptions import (
     ApiResponseError,
+    InvalidNextTokenError,
     NoAcademicTwitterAccount,
     MonthlyQuotaExceededError,
     RateLimitExceededError,
@@ -127,6 +128,15 @@ class BaseDownloader:  # pylint: disable=too-few-public-methods
                     except KeyError:
                         pass
 
+                    try:
+                        for error in results["errors"]:
+                            if "next_token" in error["parameters"]:
+                                # some endpoints (e.g., liking_users) wrongly
+                                # return a next_token
+                                raise InvalidNextTokenError
+                    except KeyError:
+                        pass
+
                     # other, not anticipated error:
                     raise ApiResponseError((results, response.headers))
 
