@@ -23,6 +23,8 @@
 __all__ = ["IncompleteDataUpdater"]
 
 
+import queue
+
 from .basedownloader import BaseDownloader
 
 
@@ -34,3 +36,25 @@ class IncompleteDataUpdater(BaseDownloader):
         super().__init__(api_key_managers)
         self._in_queue = in_queue
         self.shutdown = shutdown
+
+    @property
+    def _ids(self):
+        """Fetch IDs of missing records from `self._in_queue`."""
+        ids = []
+
+        for _ in range(100):
+            try:
+                ids.append(
+                    str(
+                        self._in_queue.get(timeout=10)
+                    )
+                )
+            except queue.Empty as exception:
+                if self.shutdown.is_set():
+                    raise exception
+                continue
+
+        if not ids:
+            raise queue.Empty()
+
+        return ids
