@@ -27,6 +27,7 @@ import datetime
 import queue
 
 from ..exceptions import (
+    InvalidNextTokenError,
     MonthlyQuotaExceededError,
     TemporaryApiResponseError,
 )
@@ -83,6 +84,10 @@ class IncompleteDataUpdaterThread(BaseDownloaderThread):
 
                 successive_unsuccessful_attempts = 0
 
+            except InvalidNextTokenError:
+                # we got a next_token, but there was no additional data
+                continue
+
             except TemporaryApiResponseError as exception:
                 # wait until we’re allowed again
                 wait_seconds = (
