@@ -31,7 +31,3 @@ class IncompleteTweetUpdaterThread(IncompleteDataUpdaterThread):
     """Wraps an IncompleteTweetUpdater to run in a separate thread."""
 
     _Downloader = IncompleteTweetUpdater
-
-    def save_batch(self, batch):
-        """Save `batch` of data returned from an API endpoint."""
-        return self.api_response_saver.save_batch_of_tweets(batch)
