@@ -31,7 +31,3 @@ class IncompleteUserUpdaterThread(IncompleteDataUpdaterThread):
     """Wraps an IncompleteUserUpdater to run in a separate thread."""
 
     _Downloader = IncompleteUserUpdater
-
-    def save_batch(self, batch):
-        """Save `batch` of data returned from an API endpoint."""
-        return self.api_response_saver.save_batch_of_users(batch)
