@@ -54,6 +54,12 @@ class FancyTwitterHistoryDownloader(BasicTwitterHistoryDownloader):
         "{t.normal} Downloaded metadata for "
         + "{t.bold}{t.magenta}{tweets: 9d} 💬 tweets "
         + "{t.normal}{t.magenta}{tweet_rate: 11.1f}/s\n"
+        + "{t.normal}                         "
+        + "{t.bold}{t.magenta}{users: 9d} 👦 users "
+        + "{t.normal}{t.magenta}{user_rate: 11.1f}/s\n"
+        + "{t.normal}                         "
+        + "{t.bold}{t.magenta}{likes: 9d} 👍 likes "
+        + "{t.normal}{t.magenta}{like_rate: 11.1f}/s\n"
         + "{t.normal} using                   "
         + "{t.bold}{t.green}{workers: 9d} 💪 workers\n"
         + "{t.normal}{t.bold} TODO:                {todo: 12d} 🚧 time slots"
@@ -64,8 +70,9 @@ class FancyTwitterHistoryDownloader(BasicTwitterHistoryDownloader):
     SHUTDOWN_ANNOUNCEMENT = "{t.bold}Cleaning up. 🛑 {t.normal}"
 
     SUMMARY = (
-        "{t.normal}Downloaded  {t.bold}{t.magenta}{tweets: 9d} 💬 tweets "
-        + "{t.normal}{t.magenta}{tweet_rate: 11.1f}/s\n"
+        "{t.normal}Downloaded  {t.bold}{t.magenta}{tweets: 9d} 💬 tweets\n"
+        + "{t.normal}            {t.bold}{t.magenta}{users: 9d} 👦 users\n"
+        + "{t.normal}            {t.bold}{t.magenta}{likes: 9d} 👍 likes\n"
         + "{t.normal}"
     )
 
@@ -85,14 +92,18 @@ class FancyTwitterHistoryDownloader(BasicTwitterHistoryDownloader):
 
     def report_progress(self):
         """Report current progress."""
-        tweet_count, tweet_rate = self._statistics
+        statistics = self.statistics
 
         with self.terminal.location(0, (self.pos_y - self.STATUS_LINES)):
             print(
                 self.STATUS.format(
                     t=self.terminal,
-                    tweets=tweet_count,
-                    tweet_rate=tweet_rate,
+                    tweets=statistics.tweets,
+                    users=statistics.users,
+                    likes=statistics.likes,
+                    tweet_rate=statistics.tweets_rate,
+                    user_rate=statistics.users_rate,
+                    like_rate=statistics.likes_rate,
                     workers=(threading.active_count() - self.NUM_MANAGERS),
                     todo=len(self._todo_deque),
                 )
@@ -114,12 +125,16 @@ class FancyTwitterHistoryDownloader(BasicTwitterHistoryDownloader):
 
         (Called right before exit)
         """
-        tweet_count, tweet_rate = self._statistics
+        statistics = self.statistics
         with self.terminal.location(0, (self.pos_y - self.STATUS_LINES)):
             print(
                 self.SUMMARY.format(
                     t=self.terminal,
-                    tweets=tweet_count,
-                    tweet_rate=tweet_rate,
+                    tweets=statistics.tweets,
+                    users=statistics.users,
+                    likes=statistics.likes,
+                    tweet_rate=statistics.tweets_rate,
+                    user_rate=statistics.users_rate,
+                    like_rate=statistics.likes_rate
                 )
             )
